@@ -28,6 +28,7 @@
 
 #include <KDBusService>
 #include <KAboutData>
+#include <KCrash>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QApplication>
@@ -40,11 +41,15 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     app.setWindowIcon(QIcon::fromTheme("system-file-manager"));
 
+    KCrash::initialize();
+
     Kdelibs4ConfigMigrator migrate(QStringLiteral("dolphin"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("dolphinrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("dolphinpart.rc") << QStringLiteral("dolphinui.rc"));
     migrate.migrate();
 
+    KLocalizedString::setApplicationDomain("dolphin");
+
     KAboutData aboutData("dolphin", i18n("Dolphin"), QStringLiteral(DOLPHIN_VERSION_STRING),
                          i18nc("@title", "File Manager"),
                          KAboutLicense::GPL,
